%define ldbm_backend berkeley

Name: openldap
Version: 2.4.23
Release: 0.4
Summary: LDAP support libraries
Group: System Environment/Daemons
License: OpenLDAP
URL: http://www.openldap.org/
Source0: ftp://ftp.OpenLDAP.org/pub/OpenLDAP/openldap-release/%{name}-%{version}.tgz
Source1: ftp://ftp.OpenLDAP.org/pub/OpenLDAP/openldap-release/%{name}-%{version}.md5
Source2: ftp://ftp.OpenLDAP.org/pub/OpenLDAP/openldap-release/%{name}-%{version}.sha1
Source3: ldap.init
Source4: ldap.sysconfig
Source5: ldap.tmpfiles

# Patches for 2.4
Patch0: openldap-slapd-conf.patch
Patch1: openldap-manpages.patch
#Patch2: openldap-security-pie.patch
#Patch3: openldap-sql-linking.patch
#Patch4: openldap-reentrant-gethostby.patch
Patch5: openldap-export-ldif.patch
#Patch6: openldap-smbk5pwd-overlay.patch
Patch7: openldap-ldaprc-currentdir.patch
Patch8: openldap-userconfig-setgid.patch

# already merged upstream
Patch100: openldap-nss-ca-selfsigned.patch
Patch101: openldap-nss-delay-token-auth.patch
Patch102: openldap-nss-db-prefix.patch
Patch103: openldap-reject-non-file-keyfiles.patch
Patch104: openldap-use-cacert-dir-and-file.patch
Patch105: openldap-cacertdir-hash-only.patch
Patch106: openldap-improve-trace-messages.patch
Patch107: openldap-nss-non-blocking.patch
Patch108: openldap-verify-self-issued-certs.patch

# patches sent upstream
Patch109: openldap-nss-cipher-suites.patch
Patch110: openldap-nss-restart-modules-fork.patch

BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root

BuildRequires:	patch, make

BuildRequires:	gdbm-devel >= 1.11-1
BuildRequires:	libtool >= 1.5.26-1
BuildRequires:	libtool-ltdl-devel >= 1.5.26-1
BuildRequires:	krb5-devel >= 1.8.3-1
BuildRequires:	openssl-devel >= 1.0.1s-1
BuildRequires:	perl >= 5.8.8-2
BuildRequires:	pkg-config
BuildRequires:	unixODBC-devel >= 2.3.4-1

Requires:	openssl >= 1.0.1s-1

# provide ldif2ldbm functionality for migrationtools
Provides: ldif2ldbm

%define _libdir64 %{_prefix}/lib64

%description
OpenLDAP is an open source suite of LDAP (Lightweight Directory Access
Protocol) applications and development tools. LDAP is a set of
protocols for accessing directory services (usually phone book style
information, but other information is possible) over the Internet,
similar to the way DNS (Domain Name System) information is propagated
over the Internet. The openldap package contains configuration files,
libraries, and documentation for OpenLDAP.

The library is available as 32-bit and 64-bit.


%package devel
Summary: LDAP development libraries and header files
Group: Development/Libraries
Requires: %{name} = %{version}-%{release}

%description devel
The openldap-devel package includes the development libraries and
header files needed for compiling applications that use LDAP
(Lightweight Directory Access Protocol) internals. LDAP is a set of
protocols for enabling directory services over the Internet. Install
this package only if you plan to develop or will need to compile
customized LDAP clients.

If you are compiling a 32-bit program, no special compiler options are
needed.

If you are compiling a 64-bit program, you have to compile and link your
application with "cc_r -q64" or "gcc -maix64".


%package servers
Summary: LDAP server
# OpenLDAP server includes Berkeley DB library, which is licensed under Sleepycat and BSD licenses)
License: OpenLDAP and (Sleepycat and BSD)
Requires: %{name} = %{version}-%{release}
Requires: openssl >= 1.0.1s-1
Group: System Environment/Daemons

%description servers
OpenLDAP is an open-source suite of LDAP (Lightweight Directory Access
Protocol) applications and development tools. LDAP is a set of
protocols for accessing directory services (usually phone book style
information, but other information is possible) over the Internet,
similar to the way DNS (Domain Name System) information is propagated
over the Internet. This package contains the slapd server and related files.


%package servers-sql
Summary: SQL support module for OpenLDAP server
Requires: %{name}-servers = %{version}-%{release}
Group: System Environment/Daemons

%description servers-sql
OpenLDAP is an open-source suite of LDAP (Lightweight Directory Access
Protocol) applications and development tools. LDAP is a set of
protocols for accessing directory services (usually phone book style
information, but other information is possible) over the Internet,
similar to the way DNS (Domain Name System) information is propagated
over the Internet. This package contains a loadable module which the
slapd server can use to read data from an RDBMS.


%package clients
Summary: LDAP client utilities
Requires: %{name} = %{version}-%{release}
Group: Applications/Internet

%description clients
OpenLDAP is an open-source suite of LDAP (Lightweight Directory Access
Protocol) applications and development tools. LDAP is a set of
protocols for accessing directory services (usually phone book style
information, but other information is possible) over the Internet,
similar to the way DNS (Domain Name System) information is propagated
over the Internet. The openldap-clients package contains the client
programs needed for accessing and modifying OpenLDAP directories.


%prep
%setup -q
export PATH=/opt/freeware/bin:$PATH

%patch0 -p1 -b .config
%patch1 -p1 -b .manpages
#%patch2 -p1 -b .security-pie
#%patch3 -p1 -b .sql-linking
#%patch4 -p1 -b .reentrant-gethostby
%patch5 -p1 -b .export-ldif
#%patch6 -p1 -b .smbk5pwd-overlay
%patch7 -p1 -b .ldaprc-currentdir
%patch8 -p1 -b .userconfig-setgid

%patch100 -p1 -b .nss-ca-selfsigned
%patch101 -p1 -b .nss-delay-token-auth
%patch102 -p1 -b .nss-db-prefix
%patch103 -p1 -b .reject-non-file-keyfiles
%patch104 -p1 -b .use-cacert-dir-and-file-dir
%patch105 -p1 -b .cacertdir-hash-only
%patch106 -p1 -b .improve-trace-messages
%patch107 -p1 -b .nss-non-blocking
%patch108 -p1 -b .verify-self-issued-certs
%patch109 -p1 -b .nss-cipher-suites
%patch110 -p1 -b .nss-restart-modules-fork

for subdir in clients-32 clients-64 servers-32 servers-64 ; do
    mkdir ${subdir}
    ln -s ../configure ${subdir}
done


%build
export CC="cc_r"

build() {
./configure \
    --prefix=%{_prefix} \
    --mandir=%{_mandir} \
    --sysconfdir=/etc \
    --localstatedir=/var \
    --with-threads=posix \
    \
    --enable-local --enable-rlookups \
    \
    --with-tls \
    --without-cyrus-sasl \
    \
    --disable-wrappers \
    \
    --enable-passwd \
    \
    --enable-cleartext \
    --enable-crypt \
    --disable-lmpasswd \
    --disable-spasswd \
    --enable-modules \
    --disable-sql \
    $@
gmake depend
gmake %{?_smp_mflags}
}

buildservers() {
build \
    --enable-plugins \
    --enable-slapd \
    --enable-bdb \
    --enable-hdb \
    --enable-ldap \
    --enable-ldbm \
    --with-ldbm-api=%{ldbm_backend} \
    --enable-meta \
    --enable-monitor \
    --enable-null \
    --enable-shell \
    --enable-sql=no \
    --disable-ndb \
    --enable-passwd \
    --enable-sock \
    --disable-perl \
    --enable-relay \
    --enable-shared \
    --disable-static \
    --enable-dynamic \
    --with-kerberos=k5only \
    --enable-overlays=mod \
    $@
}

buildclients() {
build \
    --disable-slapd \
    --enable-shared \
    --disable-static \
    --enable-dynamic \
    --without-kerberos \
    --with-pic \
    $@
}

# Kerberos support:
# - enabled in server (mainly for password checking)
# - disabled in clients (not needed, to avoid stray dependencies)

# build servers
export LIBS="-lpthread"

cd servers-64
export OBJECT_MODE=64
export LDFLAGS="-L/opt/freeware/lib64 -L/opt/freeware/lib -Wl,-blibpath:/opt/freeware/lib64:/opt/freeware/lib:/usr/lib:/lib -Wl,-bmaxdata:0x80000000"
buildservers --libdir=%{_libdir64} --libexecdir=%{_libdir64}
cd ..

cd servers-32
export OBJECT_MODE=32
export LDFLAGS="-L/opt/freeware/lib -Wl,-blibpath:/opt/freeware/lib:/usr/lib:/lib -Wl,-bmaxdata:0x80000000"
buildservers --libexecdir=%{_libdir}
cd ..

# build clients without Kerberos password-checking support, which is only
# useful in the server anyway, to avoid stray dependencies.

cd clients-64
export OBJECT_MODE=64
export LDFLAGS="-L/opt/freeware/lib64 -L/opt/freeware/lib -Wl,-blibpath:/opt/freeware/lib64:/opt/freeware/lib:/usr/lib:/lib -Wl,-bmaxdata:0x80000000"
buildservers --libdir=%{_libdir64} --libexecdir=%{_libdir64}
cd ..

cd clients-32
export OBJECT_MODE=32
export LDFLAGS="-L/opt/freeware/lib -Wl,-blibpath:/opt/freeware/lib:/usr/lib:/lib -Wl,-bmaxdata:0x80000000"
buildclients --libexecdir=%{_libdir}
cd ..


%install
[ "$RPM_BUILD_ROOT" != "/" ] && rm -rf $RPM_BUILD_ROOT

export OBJECT_MODE=64

cd servers-64
gmake install DESTDIR=${RPM_BUILD_ROOT}
cd ..

cd clients-64
gmake install DESTDIR=${RPM_BUILD_ROOT}
cd ..

(
  cd ${RPM_BUILD_ROOT}%{_bindir}
  rm -f ldapadd
  for f in * ; do
      mv -f ${f} ${f}_64
  done
  ln -s ldapmodify_64 ldapadd_64
)

export OBJECT_MODE=32

cd servers-32
gmake install DESTDIR=${RPM_BUILD_ROOT}
cd ..

cd clients-32
gmake install DESTDIR=${RPM_BUILD_ROOT}
cd ..

(
  cd ${RPM_BUILD_ROOT}%{_libdir}
  for f in *.a ; do
      /usr/bin/ar -X32 -x ${f}
  done
  cd ${RPM_BUILD_ROOT}%{_libdir64}
  for f in *.a ; do
      /usr/bin/ar -X64 -x ${f}
  done
  ln -sf ../lib/*.a .

  cd ${RPM_BUILD_ROOT}%{_libdir}/%{name}
  for f in *.a ; do
      /usr/bin/ar -X32 -x ${f}
  done
  cd ${RPM_BUILD_ROOT}%{_libdir64}/%{name}
  for f in *.a ; do
      /usr/bin/ar -X64 -x ${f}
  done
)

# add the 64-bit shared objects to the shared libraries containing already the
# 32-bit shared objects
for i in lber-2.4 ldap-2.4 ldap_r-2.4 ldif-2.4 ; do
    /usr/bin/ar -X64 -q ${RPM_BUILD_ROOT}%{_libdir}/lib${i}.a ${RPM_BUILD_ROOT}%{_libdir64}/lib${i}.so*
done


# move slapd out of %{_libdir} and %{_libdir64}
for i in acl add auth cat dn index passwd schema test ; do
    rm -f ${RPM_BUILD_ROOT}%{_sbindir}/slap${i}
done
mv ${RPM_BUILD_ROOT}%{_libdir}/slapd ${RPM_BUILD_ROOT}%{_sbindir}/
mv ${RPM_BUILD_ROOT}%{_libdir64}/slapd ${RPM_BUILD_ROOT}%{_sbindir}/slapd_64

# set up tools as symlinks to slapd
for i in acl add auth cat dn index passwd schema test ; do
    ln -s slapd ${RPM_BUILD_ROOT}%{_sbindir}/slap${i}
    ln -s slapd_64 ${RPM_BUILD_ROOT}%{_sbindir}/slap${i}_64
done

/usr/bin/strip -X32_64 ${RPM_BUILD_ROOT}%{_bindir}/* || :
/usr/bin/strip -X32_64 ${RPM_BUILD_ROOT}%{_sbindir}/* || :

# set up directories for TLS certificates
mkdir -p ${RPM_BUILD_ROOT}/etc/%{name}/cacerts
mkdir -p ${RPM_BUILD_ROOT}/etc/pki/tls/certs
# Touch the dummy slapd.pem to make rpmbuild happy
touch ${RPM_BUILD_ROOT}/etc/pki/tls/certs/slapd.pem

# set up data and runtime directories
mkdir -p ${RPM_BUILD_ROOT}/var/lib/ldap
mkdir -p ${RPM_BUILD_ROOT}/var/run/openldap

# hack the build root out of the default config files.
perl -pi -e "s|${RPM_BUILD_ROOT}||g" ${RPM_BUILD_ROOT}/etc/%{name}/*.conf

# remove buildroot from config files and manual pages
perl -pi -e "s|${RPM_BUILD_ROOT}||g" ${RPM_BUILD_ROOT}/etc/%{name}/*.conf
perl -pi -e "s|${RPM_BUILD_ROOT}||g" ${RPM_BUILD_ROOT}%{_mandir}/*/*.*

# we don't need the default files -- RPM handles changes.
rm -f ${RPM_BUILD_ROOT}/etc/%{name}/*.default
rm -f ${RPM_BUILD_ROOT}/etc/%{name}/schema/*.default

# install an init script for the servers.
mkdir -p ${RPM_BUILD_ROOT}/etc/rc.d/init.d
cp %{SOURCE3} ${RPM_BUILD_ROOT}/etc/rc.d/init.d/ldap
chmod 0755 ${RPM_BUILD_ROOT}/etc/rc.d/init.d/ldap

# install syconfig/ldap
mkdir -p ${RPM_BUILD_ROOT}/etc/sysconfig
cp %{SOURCE4} ${RPM_BUILD_ROOT}/etc/sysconfig/ldap
chmod 0644 ${RPM_BUILD_ROOT}/etc/sysconfig/ldap

# slapd.conf(5) is obsoleted since 2.3, see slapd-config(5)
# new configuration will be generated in %post
mkdir -p ${RPM_BUILD_ROOT}%{_datadir}/%{name}-servers
mkdir ${RPM_BUILD_ROOT}/etc/%{name}/slapd.d
mv ${RPM_BUILD_ROOT}/etc/%{name}/slapd.conf ${RPM_BUILD_ROOT}%{_datadir}/%{name}-servers/slapd.conf.obsolete
chmod 0644 ${RPM_BUILD_ROOT}%{_datadir}/%{name}-servers/slapd.conf.obsolete

# move doc files out of %{_sysconfdir}
mv ${RPM_BUILD_ROOT}/etc/%{name}/schema/README README.schema
mv ${RPM_BUILD_ROOT}/etc/%{name}/DB_CONFIG.example DB_CONFIG.example
chmod 0644 README.schema DB_CONFIG.example

# tweak permissions on the libraries to make sure they're correct.
chmod 755 ${RPM_BUILD_ROOT}%{_libdir}/lib*.so*
chmod 644 ${RPM_BUILD_ROOT}%{_libdir}/lib*.*a

rm -f ${RPM_BUILD_ROOT}/var/openldap-data/DB_CONFIG.example
rmdir ${RPM_BUILD_ROOT}/var/openldap-data

(
  cd ${RPM_BUILD_ROOT}
  for dir in bin sbin include lib lib64
  do
    mkdir -p usr/linux/${dir}
    cd usr/linux/${dir}
    ln -sf ../../..%{_prefix}/${dir}/* .
    cd -
  done
)


%pre servers
exit 0
# Take care to only do ownership-changing if we're adding the user.
getent group ldap > /dev/null || \
/usr/sbin/groupadd -r -g 55 ldap
if /usr/sbin/useradd -c "LDAP User" -u 55 -g ldap \
    -s /sbin/nologin -r -d /var/lib/ldap ldap 2> /dev/null ; then
    if [ -d /var/lib/ldap ] ; then
        for dbfile in /var/lib/ldap/* ; do
            if [ -f $dbfile ] ; then
                chown ldap:ldap $dbfile
            fi
        done
    fi
fi

if [ "$1" = "2" ]; then
    # guess, if database upgrade is necessary
    OLD_BDB_VERSION=$( slapd_db_upgrade -V | sed 's/.* \([0-9\.]*\)\.[0-9]*:.*/\1/' )
    NEW_BDB_VERSION=$( echo %{db_version} | sed 's/.[0-9]*$//' )

    OLD_SLAPD_VERSION=$( rpm -q --qf "%{VERSION}" openldap-servers | sed 's/\.[0-9]*$//' )
    NEW_SLAPD_VERSION=$( echo %{version} | sed 's/\.[0-9]*$//' )

    if [ "$OLD_SLAPD_VERSION" != "$NEW_SLAPD_VERSION" ]; then
        # Minor version number has changed -> slapcat/slapadd of the BDB database 
        # is necessary. Save an ldif of the database where the "% post servers" 
        # scriptlet can restore it.  Also save the database files to a "rpmorig" 
        # directory - Just In Case (TM)

        # stop the server
        if /sbin/service ldap status &>/dev/null; then 
            touch /var/lib/ldap/need_start
            /sbin/service ldap stop &>/dev/null
        fi

        files=$(echo /var/lib/ldap/{log.*,__db.*,[a]lock})
        if [ "$files" != '/var/lib/ldap/log.* /var/lib/ldap/__db.* /var/lib/ldap/[a]lock' ] ; then
            if /usr/sbin/slapcat -l /var/lib/ldap/upgrade.ldif > /dev/null 2>&1 ; then
                if [ -f /var/lib/ldap/upgrade.ldif ] ; then
                    /bin/rm -fr /var/lib/ldap/rpmorig > /dev/null 2>&1 || :
                    mkdir /var/lib/ldap/rpmorig
                    mv /var/lib/ldap/{alock,*.bdb,__db.*,log.*} /var/lib/ldap/rpmorig > /dev/null 2>&1 || :
                    cp -f /var/lib/ldap/DB_CONFIG /var/lib/ldap/rpmorig > /dev/null 2>&1 || :
                else
                    /bin/rm -f /var/lib/ldap/upgrade.ldif
                fi
            fi
        fi
    else
        if [ "$OLD_BDB_VERSION" != "$NEW_BDB_VERSION" ]; then
            # Minor version number of bdb has changed -> run db_upgrade in % post script 
    
            # stop the server
            if /sbin/service ldap status &>/dev/null; then 
                touch /var/lib/ldap/need_start
                /sbin/service ldap stop &>/dev/null
            fi

            # Ensure, that the database is correct
            /sbin/runuser -m -s /usr/sbin/slapd_db_recover -- "ldap" -h /var/lib/ldap &>/dev/null
            # Just create /var/lib/ldap/need_db_upgrade so % post knows
            touch /var/lib/ldap/need_db_upgrade &>/dev/null
        fi
    fi
fi
exit 0


%post servers
exit 0
/sbin/chkconfig --add ldap
# If there's a /var/lib/ldap/upgrade.ldif file, slapadd it and delete it.
# It was created by the % pre above.
if [ -f /var/lib/ldap/upgrade.ldif ] ; then
    /sbin/runuser -m -s /usr/sbin/slapadd -- "ldap" -l /var/lib/ldap/upgrade.ldif > /dev/null 2>&1
    rm -f /var/lib/ldap/upgrade.ldif
fi

# If there's a /var/lib/ldap/need_db_upgrade file, run db_upgrade and delete it.
# It was created by the % pre above.
if [ -f /var/lib/ldap/need_db_upgrade ]; then
    /sbin/runuser -m -s /usr/sbin/slapd_db_upgrade -- "ldap"  -h /var/lib/ldap /var/lib/ldap/*.bdb
    /sbin/runuser -m -s /usr/sbin/slapd_db_checkpoint -- "ldap" -h /var/lib/ldap -1
    rm -f /var/lib/ldap/need_db_upgrade
fi

if [ ! -f %{_sysconfdir}/pki/tls/certs/slapd.pem ] ; then
pushd %{_sysconfdir}/pki/tls/certs
umask 077
cat << EOF | make slapd.pem > /dev/null 2>&1
--
SomeState
SomeCity
SomeOrganization
SomeOrganizationalUnit
localhost.localdomain
root@localhost.localdomain
EOF
chown root:ldap slapd.pem
chmod 640 slapd.pem
popd
fi

if [ $1 -ge 1 ] ; then
    /sbin/service ldap condrestart &>/dev/null
    /sbin/service ldap status &>/dev/null
    if [ "$?" != "0" -a -f /var/lib/ldap/need_start ]; then
        /sbin/service ldap start &>/dev/null
        rm -f /var/lib/ldap/need_start &>/dev/null 
    fi
fi

exit 0


%preun servers
exit 0
if [ "$1" = "0" ] ; then
  /sbin/service ldap stop > /dev/null 2>&1 || :
  /sbin/chkconfig --del ldap
# Openldap-servers are being removed from system.
# Do not touch the database! Older versions of this
# package attempted to store database in LDIF format, so
# it can be restored later - but it's up to the administrator 
# to save the database, if he/she wants so.
fi


%clean 
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}


%files
%defattr(-,root,system)
%doc ANNOUNCEMENT CHANGES COPYRIGHT LICENSE README
%dir /etc/%{name}
%dir /etc/%{name}/cacerts
%config(noreplace) /etc/%{name}/ldap*.conf
%{_libdir}/liblber*.a
%{_libdir64}/liblber*.a
%{_libdir}/liblber*.so*
%{_libdir64}/liblber*.so*
%{_libdir}/libldap*.a
%{_libdir64}/libldap*.a
%{_libdir}/libldap*.so*
%{_libdir64}/libldap*.so*
%{_mandir}/man5/ldif.5*
%{_mandir}/man5/ldap.conf.5*
/usr/linux/lib/liblber*.a
/usr/linux/lib64/liblber*.a
/usr/linux/lib/liblber*.so*
/usr/linux/lib64/liblber*.so*
/usr/linux/lib/libldap*.a
/usr/linux/lib64/libldap*.a
/usr/linux/lib/libldap*.so*
/usr/linux/lib64/libldap*.so*


%files servers
%defattr(-,root,system)
%doc doc/guide/admin/*.html
%doc doc/guide/admin/*.png
%doc DB_CONFIG.example
%doc README.schema
%ghost %config(noreplace) /etc/pki/tls/certs/slapd.pem
%attr(0755,root,system) /etc//rc.d/init.d/ldap
%attr(0644,root,system) %dir %config(noreplace) /etc/%{name}/slapd.d
%attr(0644,root,system) %config(noreplace) /etc/sysconfig/ldap
%attr(0755,root,system) %dir %config(noreplace) /etc/%{name}/schema
%attr(0644,root,system) %config(noreplace) /etc/%{name}/schema/*.schema*
%attr(0644,root,system) %config(noreplace) /etc/%{name}/schema/*.ldif
%attr(0755,root,system) %{_sbindir}/sl*
%attr(0644,root,system) %{_mandir}/man8/*
%attr(0644,root,system) %{_mandir}/man5/slapd*.5*
%attr(0644,root,system) %{_mandir}/man5/slapo-*.5*
%attr(0700,root,system) %dir /var/lib/ldap
%attr(0755,root,system) %dir /var/run/%{name}
%attr(0644,root,system) %{_libdir}/libldif*.a
%attr(0644,root,system) %{_libdir64}/libldif*.a
%attr(0755,root,system) %{_libdir}/libldif*.so*
%attr(0755,root,system) %{_libdir64}/libldif*.so*
%attr(0755,root,system) %dir %{_libdir}/%{name}
%attr(0755,root,system) %dir %{_libdir64}/%{name}
%attr(0644,root,system) %{_libdir}/%{name}/*.a
%attr(0644,root,system) %{_libdir64}/%{name}/*.a
%attr(0755,root,system) %{_libdir}/%{name}/*.so*
%attr(0755,root,system) %{_libdir64}/%{name}/*.so*
%attr(0755,root,system) %dir %{_datadir}/%{name}-servers
%attr(0644,root,system) %{_datadir}/%{name}-servers/*
/usr/linux/lib/libldif*.a
/usr/linux/lib/libldif*.so*
/usr/linux/lib64/libldif*.so*


%files clients
%defattr(-,root,system)
%{_bindir}/*
%{_mandir}/man1/*
/usr/linux/bin/*


%files devel
%defattr(-,root,system)
%doc doc/drafts doc/rfc
%{_includedir}/*
%{_libdir}/*.la
%{_libdir64}/*.la
%{_libdir}/%{name}/*.la
%{_libdir64}/%{name}/*.la
%{_mandir}/man3/*
/usr/linux/include/*
/usr/linux/lib/*.la
/usr/linux/lib64/*.la


%changelog
* Fri Mar 04 2016 Michael Perzl <michael@perzl.org> - 2.4.23-0.4
- recompiled against latest versions

* Fri Nov 04 2011 Michael Perzl <michael@perzl.org> - 2.4.23-0.3
- fixed some spec file inconsistencies

* Thu Jan 27 2011 Michael Perzl <michael@perzl.org> - 2.4.23-0.2
- fixed some incompatibilities with IBM LDAP,
  all symlinks (bin,lib,lib64,include) now point to /usr/linux instead of /usr

* Thu Jan 27 2011 Michael Perzl <michael@perzl.org> - 2.4.23-0.1
- first version for AIX V5.1 and higher
